<?php
// Max Content Width
if ( ! isset( $content_width ) ) { $content_width = 770; }

function richtaste_content_width() {
    if ( is_page_template( 'page-fullwidth.php' )  || is_page_template( 'page-fullwidth-no-title.php' )   ) {
        global $content_width;
        $content_width = 1200;
    }
}
add_action( 'template_redirect', 'richtaste_content_width' );


// Scripts and styles
function richtaste_scripts() {

	// Load our main stylesheet.
    wp_enqueue_style( 'richtaste-mainstyle', get_template_directory_uri() . '/style.css' );

	// Add jQuery
    wp_enqueue_script('jquery-core');
    wp_enqueue_script( 'msn-main', get_template_directory_uri() . '/assets/js/app.js', array('jquery'), '1.0', true);

    // Comments Reply
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

}
add_action( 'wp_enqueue_scripts', 'richtaste_scripts' );

// Editor Styles
function richtaste_editor_styles() {
    add_editor_style( 'assets/css/editor-style.css' );
}
add_action( 'admin_init', 'richtaste_editor_styles' );

// Setup 
if ( ! function_exists( 'richtaste_setup' ) ) :

function richtaste_setup() {

    // Translation Ready
    load_theme_textdomain( 'richtaste', get_template_directory() . '/languages' );

    // RSS feed links
    add_theme_support( 'automatic-feed-links' );

    // Document title 
    add_theme_support( 'title-tag' );

    // Custom Logo
    add_theme_support( 'custom-logo', array(
        'height'      => 200,
        'width'       => 400,
        'flex-width'  => true,
        'flex-height' => true,
        'header-text' => array( 'site-title', 'site-description' ),
    ) );

    //Post Thumbnails & Image Sizes
    add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size( 740, 458, true );
    add_image_size( 'loop-featured-first', 740, 458, true );
    add_image_size( 'loop-featured-four', 355, 229, true );
    add_image_size( 'loop-featured-image', 770, 99999 );

    // Menus
    register_nav_menus( array(
        'primary' => __( 'Primary Menu', 'richtaste' ),
        'iconmenu' => __( 'Icon Menu', 'richtaste' ),
        'footer' => __( 'Footer Navigation', 'richtaste' ),
    ) );

    // HTML5 Forms
    add_theme_support( 'html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

    // Post Formats
    add_theme_support( 'post-formats', array(
        'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat'
    ) );


    // Woo Commerce Support
    if ( function_exists( 'is_woocommerce' ) ) {

        function richtaste_woo_widgets_init() {

             // Woo Shop Sidebar
             register_sidebar( array(
            'name'          => __( 'Woo Sidebar Widget Area', 'richtaste' ),
            'id'            => 'woo-sidebar-widget-area',
            'description'   => __( 'Add widgets here to appear in the sidebar of the shop archives.', 'richtaste' ),
            'before_widget' => '<aside id="%1$s" class="small-6 medium-4 large-12 columns widget top-widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h2 class="widget-title">',
            'after_title'   => '</h2>',
             ) );
        };
        add_action( 'widgets_init', 'richtaste_woo_widgets_init' );

        add_theme_support( 'woocommerce' );
        remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10);  
        remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
        remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10); 
        remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
        add_action( 'woocommerce_after_shop_loop', 'richtaste_pagination', 10 );   
            if ( function_exists( 'richtaste_pagination' ) ) { 
              richtaste_pagination(); 
            } ;
        remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
        remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
        remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
        
        // Shop Select Menus
        add_action( 'woocommerce_before_shop_loop', 'richtaste_shopselect', 10 );
    
        function richtaste_shopselect() {
        
        if ( has_nav_menu( 'menushop' ) ) {
            echo'<div class="menushopwrap">';
            wp_nav_menu( array( 'theme_location' => 'menushop','menu_class' => 'dropdown menu',
              'items_wrap'      => '<ul id="%1$s" class="menushop vertical medium-horizontal menu" data-responsive-menu="accordion medium-dropdown">%3$s</ul>',
              'fallback_cb' => 'false',
              'walker' => new richtaste_F6_TOPBAR_MENU_WALKER(),
        ) );
        echo '</div>';
        
        }  

        }
        
        register_nav_menus( array(
            
            'menushop' => __( 'Menu Shop', 'richtaste' ),
        
        ) );

        function richtaste_wc_hide_page_title()
        {
            if( !is_shop() ) // is_shop is the conditional tag
                return true;
        }
        add_filter( 'woocommerce_show_page_title', 'richtaste_wc_hide_page_title' );
        
        // Display 12 products per page. Goes in functions.php
        add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 12;' ), 20 );   
        
        function richtaste_dequeue_script() {
            wp_dequeue_script('chosen');
            wp_dequeue_script('select2');
        }
        
        add_action( 'wp_print_scripts', 'richtaste_dequeue_script', 100 ); 

        /**
         * Optimize WooCommerce Scripts
         * Remove WooCommerce Generator tag, styles, and scripts from non WooCommerce pages.
         */
        add_action( 'wp_enqueue_scripts', 'richtaste_child_manage_woocommerce_styles', 99 );
        
        function richtaste_child_manage_woocommerce_styles() {
            //remove generator meta tag
            remove_action( 'wp_head', array( $GLOBALS['woocommerce'], 'generator' ) );
            
        
            //first check that woo exists to prevent fatal errors
            if ( function_exists( 'is_woocommerce' ) ) {
                
                //dequeue scripts and styles
                if ( ! is_woocommerce() && ! is_cart() && ! is_checkout() && ! is_page_template('page-front.php') ) {
                    wp_dequeue_style( 'woocommerce-general' );
                    wp_dequeue_style( 'woocommerce-layout' );
                    wp_dequeue_style( 'woocommerce-smallscreen' );
                    wp_dequeue_style( 'woocommerce_frontend_styles' );
                    wp_dequeue_style( 'woocommerce_fancybox_styles' );
                    wp_dequeue_style( 'woocommerce_chosen_styles' );
                    wp_dequeue_style( 'woocommerce_prettyPhoto_css' );
                    wp_dequeue_script( 'wc_price_slider' );
                    wp_dequeue_script( 'wc-single-product' );
                    wp_dequeue_script( 'wc-add-to-cart' );
                    wp_dequeue_script( 'wc-cart-fragments' );
                    wp_dequeue_script( 'wc-checkout' );
                    wp_dequeue_script( 'wc-add-to-cart-variation' );
                    wp_dequeue_script( 'wc-single-product' );
                    wp_dequeue_script( 'wc-cart' );
                    wp_dequeue_script( 'wc-chosen' );
                    wp_dequeue_script( 'woocommerce' );
                    wp_dequeue_script( 'prettyPhoto' );
                    wp_dequeue_script( 'prettyPhoto-init' );
                    wp_dequeue_script( 'jquery-blockui' );
                    wp_dequeue_script( 'jquery-placeholder' );
                    wp_dequeue_script( 'fancybox' );
                    wp_dequeue_script( 'jqueryui' );
                }
            }
        
        }
    }
} // first check if Woo Commerce is activated

endif; // richtaste_setup
add_action( 'after_setup_theme', 'richtaste_setup' );


// Register Widget Areas
function richtaste_widgets_init() {
    
    // Primary Sidebar
    register_sidebar( array(
        'name'          => __( 'Primary Sidebar', 'richtaste' ),
        'id'            => 'sidebar-1',
        'description'   => __( 'Add widgets here to appear in your sidebar. This widget area stretches over the full width of the sidebar.', 'richtaste' ),
        'before_widget' => '<aside id="%1$s" class="widget sidebar-widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );

    // Secondary Sidebar
    register_sidebar( array(
        'name'          => __( 'Secondary Sidebar', 'richtaste' ),
        'id'            => 'sidebar-2',
        'description'   => __( 'Add widgets here to appear in your sidebar. This widget area stretches half the width of the sidebar.', 'richtaste' ),
        'before_widget' => '<aside id="%1$s" class="widget sidebar-widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );

    // Tertiary Sidebar
    register_sidebar( array(
        'name'          => __( 'Tertiary Sidebar', 'richtaste' ),
        'id'            => 'sidebar-3',
        'description'   => __( 'Add widgets here to appear in your sidebar. This widget area stretches half the width of the sidebar.', 'richtaste' ),
        'before_widget' => '<aside id="%1$s" class="widget sidebar-widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );

    
    // Top Widget Area
    register_sidebar( array(
        'name'          => __( 'Top Widget Area', 'richtaste' ),
        'id'            => 'top-widget-area',
        'description'   => __( 'Add widgets here to appear on top of your page below the Hero Image', 'richtaste' ),
        'before_widget' => '<div class="row"><aside id="%1$s" class="medium-12 columns widget top-widget %2$s">',
        'after_widget'  => '</aside></div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );


    // Above Comments Widget Area
    register_sidebar( array(
        'name'          => __( 'Above Comments Widget Area', 'richtaste' ),
        'id'            => 'above-comments-widget-area',
        'description'   => __( 'Add widgets here to appear above the Comments Section', 'richtaste' ),
        'before_widget' => '<div class="row"><aside id="%1$s" class="medium-12 columns widget top-widget %2$s">',
        'after_widget'  => '</aside></div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );

    // Above Related Posts Widget Area
    register_sidebar( array(
        'name'          => __( 'Above Related Posts Widget Area', 'richtaste' ),
        'id'            => 'above-related-posts-widget-area',
        'description'   => __( 'Add widgets here to appear above the Related Posts Section', 'richtaste' ),
        'before_widget' => '<div class="row"><aside id="%1$s" class="medium-12 columns widget top-widget %2$s">',
        'after_widget'  => '</aside></div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );

    // First Footer Widget Area
    register_sidebar( array (
        'name' => __( 'First Footer Widget Area', 'richtaste' ),
        'id' => 'first-footer-widget-area',
        'description' => __( 'Add widgets here to appear in the first footer widget area.' , 'richtaste' ),
        'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
        'after_widget' => "</aside>",
        'before_title' => '<h2 class="widget-title widget-title-bottom">',
        'after_title' => '</h2>',
    ) );

    // Second Footer Widget Area
    register_sidebar( array (
        'name' => __( 'Second Footer Widget Area', 'richtaste' ),
        'id' => 'second-footer-widget-area',
        'description' => __( 'Add widgets here to appear in the second footer widget area.' , 'richtaste' ),
        'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
        'after_widget' => "</aside>",
        'before_title' => '<h2 class="widget-title widget-title-bottom">',
        'after_title' => '</h2>',
    ) );

    // Third Footer Widget Area
    register_sidebar( array (
        'name' => __( 'Third Footer Widget Area', 'richtaste' ),
        'id' => 'third-footer-widget-area',
        'description' => __( 'Add widgets here to appear in the third footer widget area.' , 'richtaste' ),
        'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
        'after_widget' => "</aside>",
        'before_title' => '<h2 class="widget-title widget-title-bottom">',
        'after_title' => '</h2>',
    ) );

    // Fourth Footer Widget Area
    register_sidebar( array (
        'name' => __( 'Fourth Footer Widget Area', 'richtaste'),
        'id' => 'fourth-footer-widget-area',
        'description' => __( 'Add widgets here to appear in the fourth footer widget area.' , 'richtaste' ),
        'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
        'after_widget' => "</aside>",
        'before_title' => '<h2 class="widget-title widget-title-bottom">',
        'after_title' => '</h2>',
    ) );

       // Bottom Widget Area
    register_sidebar( array(
        'name'          => __( 'Bottom Widget Area', 'richtaste' ),
        'id'            => 'bottom-widget-area',
        'description'   => __( 'Add widgets here to appear on bottom of your page.', 'richtaste' ),
        'before_widget' => '<div class="row"><aside id="%1$s" class="medium-12 columns widget bottom-widget %2$s">',
        'after_widget'  => '</aside></div>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ) );

}
add_action( 'widgets_init', 'richtaste_widgets_init' );

// Primary Menu Walker
class richtaste_F6_TOPBAR_MENU_WALKER extends Walker_Nav_Menu
{        
    function start_lvl( &$output, $depth = 0, $args = array() ) {
        $indent = str_repeat("\t", $depth);
        $output .= "\n$indent<ul class=\"vertical menu\" data-submenu>\n";
    }
}
 
//Optional fallback
function richtaste_f6_topbar_menu_fallback($args)
{
    
    $walker_page = new Walker_Page();
    $fallback = $walker_page->walk(get_pages(), 0);
    $fallback = str_replace("<ul class='children'>", '<ul class="children submenu menu vertical" data-submenu>', $fallback);
    
    echo '<ul class="dropdown menu data-dropdown-menu">'.$fallback.'</ul>';
}

// Display Date
if ( ! function_exists( 'richtaste_date' ) ) :
/**
 * Gets a nicely formatted string for the published date.
 */
function richtaste_date() {
    $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
    if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
        $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
    }

    $time_string = sprintf( $time_string,
        get_the_date( DATE_W3C ),
        get_the_date(),
        get_the_modified_date( DATE_W3C ),
        get_the_modified_date()
    );

    // Wrap the time string in a link, and preface it with 'Posted on'.
    return sprintf(
        /* translators: %s: post date */
        __( '<span class="screen-reader-text">Posted on</span> %s', 'richtaste' ), $time_string );
}
endif;


// Excerpt Lenght
function richtaste_custom_excerpt_length( $length ) {
    return 40;
}
add_filter( 'excerpt_length', 'richtaste_custom_excerpt_length', 999 );


// Ellipse
function richtaste_new_excerpt_more($more) {
       global $post;
    return ' ...';
}
add_filter('excerpt_more', 'richtaste_new_excerpt_more');

function richtaste_powered_by() {
    global $richtaste_powered_by;
      echo '<div class="poweredby row"><div class="column"><a href="https://richwp.com/themes/lifestyle-fashion-wordpress-theme/" target="_blank">RichTaste - Food & Fashion WordPress Theme</a></div></div>';
}

// Pagination - Thanx to Ole Fredrik https://foundationpress.olefredrik.com/
if ( ! function_exists( 'richtaste_pagination' ) ) :
function richtaste_pagination() {
    global $wp_query;
    $big = 999999999; 
    $paginate_links = paginate_links( array(
        'base' => str_replace( $big, '%#%', html_entity_decode( get_pagenum_link( $big ) ) ),
        'current' => max( 1, get_query_var( 'paged' ) ),
        'total' => $wp_query->max_num_pages,
        'mid_size' => 2,
        'prev_next' => false,
        'type' => 'list',
    ) );
    $paginate_links = str_replace( "<ul class='page-numbers'>", "<ul class='pagination'>", $paginate_links );
    $paginate_links = str_replace( '<li><span class="page-numbers dots">', "<li><a href='#'>", $paginate_links );
    $paginate_links = str_replace( "<li><span class='page-numbers current'>", "<li class='current'><a href='#'>", $paginate_links );
    $paginate_links = str_replace( '</span>', '</a>', $paginate_links );
    $paginate_links = str_replace( "<li><a href='#'>&hellip;</a></li>", "<li><span class='dots'>&hellip;</span></li>", $paginate_links );
    $paginate_links = preg_replace( '/\s*page-numbers/', '', $paginate_links );

    if ( $paginate_links ) {
        echo '<div class="pagination-centered">';
        echo '<div class="previouspostlinks">';
            previous_posts_link( '<span class="icon-left-open-big"></span>' ); 
        echo '</div>';
        echo $paginate_links;
        echo '<div class="nextpostlinks">';
             next_posts_link( '<span class="icon-right-open-big"></span>');
        echo '</div>';
        echo '</div><!--// end .pagination -->';
    }
}

endif;

/* Featured Posts from Menu List */
include "inc/functions-menu-list.php";

// Customizer additions.
require get_template_directory() . '/inc/richwp-options.php';
 
?>